# Freenit Backend
![freenit badge](https://github.com/freenit-framework/backend/actions/workflows/pythonapp.yml/badge.svg)

[Documentation](https://freenit.org/backend/)

[Source](https://github.com/freenit-framework/backend)

Freenit is based on

* [FastAPI](https://fastapi.tiangolo.com/)
* [FastAPI Users](https://fastapi-users.github.io/fastapi-users/)
* [Ormar](https://github.com/collerek/ormar)
